Praxis Seizure: Toronto Toronto, Ontario March 14th 1998 3R+F 9 players Dallas Card https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/hScib3RFNgA/discussion Theft Without The Thamaturgy Crypt (12 cards, min=20, max=40, avg=7.83) ------------------------------------------ 4x François Villon 10 AUS CEL PRE chi obf pot prince Toreador:2 2x Hannibal 10 AUS DEM OBF cel dom cardinal Malkavian antitribu:2 2x Quira, The Bitch Queen 6 AUS OBF obt tha Malkavian antitribu:2 1x Virgil 8 AUS DEM OBF cel bishop Malkavian antitribu:2 1x Artemis 6 DEM OBF aus cel for Malkavian antitribu:2 1x Claven 4 aus dem obf Malkavian antitribu:2 1x Dorian Strack 4 AUS cel Toreador:1 Library (90 cards) Master (23) 1x Art Museum 5x Blood Doll 3x Direct Intervention 1x Elysium: The Arboretum 1x Golconda: Inner Peace 1x Institution Hunting Ground 1x Malkavian Dementia 1x Metro Underground 2x Minion Tap 1x Secure Haven 1x Society Hunting Ground 2x Society of Leopold 1x Strained Vitae Supply 2x Tomb of Rameses III Action (7) 2x Kindred Spirits 1x Precognizant Mobility 2x Return to Innocence, The 2x Revelations Equipment (5) 2x Enchanted Marionette 1x Ivory Bow 2x Talbot's Chainsaw Action Modifier (20) 6x Cloak the Gathering 2x Confusion 2x Elder Impersonation 2x Eyes of Chaos 6x Lost in Crowds 2x Mask of a Thousand Faces Reaction (18) 2x Enhanced Senses 2x Fast Reaction 4x Spirit's Touch 1x Telepathic Counter 7x Telepathic Misdirection 2x Wake with Evening's Freshness Combat (17) 4x Acrobatics 2x Aura Reading 3x Behind You! 2x Blur 1x Coma 5x Preternatural Evasion